==> lxqt-policykit_2.2.0.orig.tar.xz: lxqt-policykit-2.2.0/translations/lxqt-policykit-agent_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="85"/>
        <location filename="../src/policykitagent.cpp" line="183"/>
        <source>PolicyKit Information</source>
        <translation>Informacions de PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="82"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation>Una autra autentificacion es en cor. Tornatz ensajar mai tard.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="160"/>
        <source>Authorization Failed</source>
        <translation>Fracàs de l’autorizacion</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="160"/>
        <source>Authorization failed for some reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="176"/>
        <source>PolicyKit Error</source>
        <translation>Error de PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Autentificacion requerida</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identitat :</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <location filename="../src/policykitagentgui.cpp" line="74"/>
        <source>Password:</source>
        <translation>Senhal :</translation>
    </message>
</context>
</TS>

==> lxqt-policykit_2.3.0.orig.tar.xz: lxqt-policykit-2.3.0/translations/lxqt-policykit-agent_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="85"/>
        <location filename="../src/policykitagent.cpp" line="183"/>
        <source>PolicyKit Information</source>
        <translation>Informacions de PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="82"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation>Una autra autentificacion es en cor. Tornatz ensajar mai tard.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="160"/>
        <source>Authorization Failed</source>
        <translation>Fracàs de l’autorizacion</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="160"/>
        <source>Authorization failed for some reason</source>
        <translation>Fracàs de l’autorizacion per una rason quina que siá</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="176"/>
        <source>PolicyKit Error</source>
        <translation>Error de PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Autentificacion requerida</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identitat :</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <location filename="../src/policykitagentgui.cpp" line="74"/>
        <source>Password:</source>
        <translation>Senhal :</translation>
    </message>
</context>
</TS>
